/*
Test client showing how the Forst Bus Java API can be used.

This code assumes a three node cluster is running on localhost, configured as follows:

# forest-bus-server -id testcluster -cbor :5000 -name :3000 -path ~/forest-data/bus1
# forest-bus-server -id testcluster -cbor :5001 -name :3001 -path ~/forest-data/bus2
# forest-bus-server -id testcluster -cbor :5002 -name :3002 -path ~/forest-data/bus3

On first start the servers need configuring with their peers:
# forest-admin -id testcluster peers :3000,:3001,:3002

A test topic also needs to have been created:
# forest-admin -id testcluster topic test
*/


import com.fasterxml.jackson.dataformat.cbor.*;
import com.owlfish.forestbus.*;
import java.util.Arrays;


public class Test {
	public static void main (String[] args) {
		System.out.println ("Test");
		try {
			String[] nodes = {"localhost:5000", "localhost:5001", "localhost:5002"};
			ForestClient fc = new ForestClient ("testcluster", nodes);
			GetMessagesResult messages = fc.getMessages("test", 1, 1, false);
			for (byte[] msg : messages.receivedMessages) {
				System.out.println ("Message retrieved: " + Arrays.toString(msg));
			}
			long maxIndex = fc.getTopicMaxAvailableIndex("test");
			System.out.println("Max available message index " + Long.toString(maxIndex));

			byte[] msgToSend = "A test from Java!".getBytes();
			byte[][] msgBatch = new byte[1][];
			msgBatch [0] = msgToSend;

			long ids[] = fc.sendMessages ("test", msgBatch, false);
			System.out.println ("Created message " + Long.toString (ids[0]));

			msgToSend = "A further test from Java!".getBytes();
			msgBatch [0] = msgToSend;
			ids = fc.sendMessages ("test", msgBatch, false);
			System.out.println ("Created message " + Long.toString (ids[0]));
			
			fc.close();
		}
		catch (Exception e) {
			System.out.println("Exception during forest bus client call: " + e.toString());
			e.printStackTrace();
		}
	}
}